betty.ancestry.person_name module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.person_name module

Data types to describe people’s names.

final class betty.ancestry.person_name.PersonName

  Bases: `ShorthandPluginBase`, `HasLocale`, `HasCitations`, `HasPrivacy`, `Entity`

  A name for a `betty.ancestry.person.Person`.

  __init__(*, person: Person | ToOneResolver[Person], id: str | None = None, individual: str | None = None, affiliation: str | None = None, privacy: Privacy | None = None, public: bool | None = None, private: bool | None = None, locale: str = 'und')
  property affiliation: str | None

    The name’s affiliation, or family component.

    Also known as:

    - last name

    - surname

  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  property individual: str | None

    The name’s individual component.

    Also known as:

    - first name

    - given name

  property label: Localizable

    The entity’s human-readable label.

  async classmethod linked_data_schema(project: Project) → JsonLdObject

    Define the JSON Schema for `betty.json.linked_data.LinkedDataDumpable.dump_linked_data()`.

  person

    The person whose name this is.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.